GitError

Enum GitError 

pub enum GitError {
Show 27 variants EmptySpec, NoCommits, RemoteNotFound(String), RemoteHasNoUrl(String), NonUtf8RemoteUrl { remote: String, source: FromUtf8Error, }, Bundle(Box<BundleError>), Panic(JoinError), Io(Error), RevParse(Error), FindObject(Error), PeelToKind(Error), HeadCommit(Error), DecodeCommit(Error), ShortId(Error), MergeBase(Box<Error>), WorktreeStream(Box<Error>), WorktreeArchive(Box<Error>), FindRemote(Box<Error>), Open(Box<Error>), Discover(Box<Error>), ConfigKeyParse(String), ConfigInvalidSectionName { name: String, source: Error, }, ConfigInvalidValueName { name: String, source: Error, }, ConfigKeyNotSet(String), ConfigParse(Box<Error>), ConfigLock(Box<Error>), TagChainCycle { oid: ObjectId, },
}
Aggregate error for the helpers in this module.

Variants



EmptySpec

Caller passed an empty rev-spec.



NoCommits

head_commit() was called on a repository with no commits.



RemoteNotFound(String)

Named remote does not exist.



RemoteHasNoUrl(String)

Remote exists but has neither a fetch nor a push URL.



NonUtf8RemoteUrl

Remote URL is not valid UTF-8.

Fields

remote: String

The remote whose URL could not be decoded.

source: FromUtf8Error

The underlying decode error.



Bundle(Box<BundleError>)

Native bundle operation failed.



Panic(JoinError)

A spawn_blocking task panicked.



Io(Error)

Local I/O error.



RevParse(Error)

rev_parse_single failed.



FindObject(Error)

Could not find an object referenced from a rev-spec.



PeelToKind(Error)

Could not peel an object to the requested kind.



HeadCommit(Error)

head_commit() failed.



DecodeCommit(Error)

Could not decode commit object.



ShortId(Error)

Computing a short id failed.



MergeBase(Box<Error>)

Underlying merge-base computation failed.



WorktreeStream(Box<Error>)

Building the worktree stream for archive emission failed.



WorktreeArchive(Box<Error>)

Writing the archive to disk failed.



FindRemote(Box<Error>)

find_remote() failed.



Open(Box<Error>)

gix::open() failed.



Discover(Box<Error>)

gix::discover() failed when locating the config file.



ConfigKeyParse(String)

Dotted config key was empty, contained empty segments, or had no ..



ConfigInvalidSectionName

gix-config rejected a section header (invalid name characters).

Fields

name: String

The rejected section name.

source: Error

Underlying validator error.



ConfigInvalidValueName

gix-config rejected a value name (invalid characters or non-alphabetic start).

Fields

name: String

The rejected value name.

source: Error

Underlying validator error.



ConfigKeyNotSet(String)

--unset was issued for a key that is not present in the local config.



ConfigParse(Box<Error>)

Failed to parse the existing .git/config file.



ConfigLock(Box<Error>)

Failed to acquire a lock file for an atomic file write (e.g. .git/config.lock, .git/shallow.lock).



TagChainCycle

A tag chain visited the same OID twice — i.e. a cycle. Real git objects cannot form cycles (each tag’s OID is determined by the SHA-1 of its content, which includes the target OID, so a cycle would require a SHA-1 preimage). This guard exists for adversarial or corrupted ODB inputs that bypass the hashing invariant.

Fields

oid: ObjectId

The OID at which the cycle was detected.