pub fn init() -> Result<ReloadHandle, InitError>Expand description
Initialise the global subscriber and return a handle to its filter.
Errors
Returns InitError if a global subscriber is already set (the
subscriber can only be initialised once per process). The helper
bins call this exactly once from run_main; tests that set up their
own subscriber will receive Err here.